; WHEATLEY - When HI Evades Analysis, This Lists EverYthing

; Since GLADOS is prone to failing at the plotting stage for an unknown reason,
; this program uses the data in "Catalogue.txt" to plot the spectra. User must
; have already run the CHELL matching program or created their own catalogue 
; file of the same format (see below).
; Since GLADOS has already computed the important parameters there is no need to
; remeasure everything, only to correct the baseline and plot stuff. This is JUST
; a plotting program, nothing more. Requires cube name and channels to search as 
; input. Vtol should be the same as in GLADOS but it won't really matter if it
; isn't.
; The only things the user need adjust are z1, z2, vtol and averagecube.


z1 = 2855       ; Minimum channel
z2 = 3900       ; Maximum channel
sizez = z2 - z1
vtol = 600.0

averagecube = string('/home/virgo/spxrt/AGES7448Stuff/AGES7448_hann3.fits')
; print, 'Reading in cube...'
fxread, averagecube, DATAC, HEADERC

deltav = fxpar(headerc, 'CDELT3')/(-1000.0)
ctol = fix(vtol/deltav) 

channel = intarr(sizez)

for i = z1, z2-1 do begin 
   channel(i-z1) = i
endfor

; Parameters to convert channels to velocity
ls = 299792458D			; Lightspeed
zref = fxpar(headerc, 'CRPIX3')	; Reference channel 
zvel = fxpar(headerc, 'CRVAL3') ; Velocity of reference channel
lamda0=0.2110611405413D		; Rest wavelength of HI
f0 = 1420.40575177E6	        ; Rest frequency of HI
lamref  = ((zvel*lamda0) / ls) + lamda0     ; Wavelength of reference channel
fref = ls / lamref		; Frequency of reference channel
deltaf = 100E6 / 4096.0         ; Frequency resolution

; Make an array of velocity values based on channel numbers
velocity = -(ls*( ((channel - zref)*deltaf + fref - f0)/((channel - zref)*deltaf + fref) ))/1000.0


; Set and open the catalogue file for postscript printing
set_plot, 'PS'
device, filename='Catalogue.eps'
!p.multi = [0,2,5]

print, 'Plotting spectra...'
; Make an array of velocity values based on channel numbers
velocity = -(ls*( ((channel - zref)*deltaf + fref - f0)/((channel - zref)*deltaf + fref) ))/1000.0

readcol, 'Catalogue.txt', x, y, z, ra, dec, velocity2, SN, vmin, mask1, mask2, GroupID, GroupSize, format='LL, LL, LL, A, A, F, F, F, LL, LL, LL, LL'
length = size(x, /DIMENSIONS)
l = length(0)

for i=0, l-1 do begin
   value=DATAC(x(i),y(i),z1:z2-1)

   ; Create arrays with masked channels for estimating the baseline
   tempflux = fltarr(sizez-1-ctol)
   tempchan = fltarr(sizez-1-ctol)

   j = 0
   for k = 0, sizez-1 do begin
      if (k lt (mask1(i)-z1)) or (k gt (mask2(i)-z1)) then begin
         tempflux(j) = value(0,0,k)
         tempchan(j)= channel(k)
         j = j + 1
      endif
   endfor
   
   fpoly = poly_fit(tempchan, tempflux(0:sizez-2-ctol), 1)
   fapprox = fpoly(0) + fpoly(1)*channel

   fcorrected = value(0,0,0:sizez-1) - fapprox
   xyad, HEADERC, x(i), y(i), ra, dec
   coords=adstring(ra, dec)
   sc = strsplit(coords, ' ', /extract)
   coords=' '+sc[0]+':'+sc[1]+':'+sc[2]+' '+sc[3]+':'+sc[4]+':'+sc[5]

   SNs=string(SN(i))
   vws=string(vmin(i))
   fulltitle = 'RA, Dec = '+coords+' SN = '+SNs+' W50 min = '+vws
   propertitle = strcompress(fulltitle)

   
   plot, velocity, fcorrected(0,0,0:sizez-1), xrange=[velocity(sizez-1),velocity(0)], title=propertitle ; Calibrated spectrum

   oplot, [velocity(mask1(i)-z1),velocity(mask1(i)-z1)], [-1,1];, color=-500                   ;Masked range
   oplot, [velocity(mask2(i)-z1),velocity(mask2(i)-z1)], [-1,1];, color=-500


endfor

print, 'DONE !'

device, /close

end
